@@ -208,7 +208,7 @@ class ScaLAPACK4py:
 
   def scatter(self, src_data, dest_desc, dest_data):
     m = dest_desc.m
-    n = dest_desc.m
+    n = dest_desc.n
     common_blacs_ctx = dest_desc.ctxt
     src_blacs_ctx = self.make_blacs_context(self.get_system_context(common_blacs_ctx), 1, 1)
     if src_blacs_ctx != -1:
@@ -222,7 +222,7 @@ class ScaLAPACK4py:
 
   def gather(self, src_desc, src_data, dest_data):
     m = src_desc.m
-    n = src_desc.m
+    n = src_desc.n
     common_blacs_ctx = src_desc.ctxt
     gatherer_blacs_ctx = self.make_blacs_context(self.get_system_context(common_blacs_ctx), 1, 1)
     if gatherer_blacs_ctx != -1:
